<script setup>
import { color } from "~/composables/colors.ts"
import Button from "~/components/ui/Button.vue"
import Card from "~/components/ui/Card.vue"
</script>

# Using Color

## Add color via props

[Alerts](components/ui/alert) support [Pastel](#pastel) attributes. [Buttons](components/ui/button) accept [Color](#color) and [Variant](#variant) attributes. [Cards](components/ui/card) accept [Pastel](#pastel), [Variant](#variant), [Neutral](#neutral) and [Raised](#raised) attributes.

```vue-html
<Card title="solid red" solid red />
```

<Card title="solid red" solid red />

## Add color to a any component or Html tag

1. Choose a
   - [base color](#colors) (`primary | secondary | destructive`) or
   - [pastel color](#pastel) (`blue | red | green | yellow`) or
   - [neutral beige or gray](#neutral) (`default`) for surfaces
2. Choose a [variant](#color-variants) (`solid | ghost | outline`)
3. Add [interactivity and raise the surface](#interactive-andor-raised)

```vue
<script setup>
import { color } from "~/composables/colors.ts";
</script>

<template>
  <div v-bind="color('primary solid interactive raised')" />
</template>
```

<div :class="$style.swatch" v-bind="color('primary solid interactive raised')" />

## Base colors

### Neutral

<div :class="$style.swatch" v-bind="color('default solid')" />
<div :class="$style.swatch" v-bind="color('default solid interactive')" />
<div :class="$style.swatch" v-bind="color('default solid raised')" />
<div :class="$style.swatch" v-bind="color('default solid interactive')" />

### Color

Primary

<div :class="$style.swatch" v-bind="color('primary solid')" />
<div :class="$style.swatch" v-bind="color('primary solid interactive')" />
<div :class="$style.swatch" v-bind="color('primary solid raised')" />
<div :class="$style.swatch" v-bind="color('primary solid interactive')" />

Secondary

<div :class="$style.swatch" v-bind="color('secondary solid')" />
<div :class="$style.swatch" v-bind="color('secondary solid interactive')" />
<div :class="$style.swatch" v-bind="color('secondary solid raised')" />
<div :class="$style.swatch" v-bind="color('secondary solid interactive')" />

Destructive

<div :class="$style.swatch" v-bind="color('destructive solid')" />
<div :class="$style.swatch" v-bind="color('destructive solid interactive')" />
<div :class="$style.swatch" v-bind="color('destructive solid raised')" />
<div :class="$style.swatch" v-bind="color('destructive solid interactive')" />

### Pastel

Blue, Red, Purple, Green, Yellow

<div :class="$style.swatch" v-bind="color('blue solid interactive')" />
<div :class="$style.swatch" v-bind="color('red solid interactive')" />
<div :class="$style.swatch" v-bind="color('purple solid interactive')" />
<div :class="$style.swatch" v-bind="color('green solid interactive')" />
<div :class="$style.swatch" v-bind="color('yellow solid interactive')" />

---

### Variant

Solid (default), Ghost, Outline

<Button round shadow icon="bi-x" solid />
<div :class="$style.swatch" v-bind="color('solid raised')">
<Button round icon="bi-x" ghost />
<Button round icon="bi-x" outline />
</div>

<br/>

<Button round shadow icon="bi-x" primary solid />
<div :class="$style.swatch" v-bind="color('primary solid')">
<Button round icon="bi-x" primary ghost />
<Button round icon="bi-x" primary outline />
</div>

---

### Interactive and/or Raised

<div v-bind="color('default solid')" style="display:inline-flex;">
    <div :class="$style.swatch" v-bind="color('solid')" />
    <div :class="$style.swatch" v-bind="color('solid interactive')" />
</div>
<div v-bind="color('secondary solid')" style="display:inline-flex;">
    <div :class="$style.swatch" v-bind="color('solid')" />
    <div :class="$style.swatch" v-bind="color('solid interactive')" />
</div>
<div v-bind="color('primary solid')" style="display:inline-flex;">
    <div :class="$style.swatch" v-bind="color('solid')" />
    <div :class="$style.swatch" v-bind="color('solid interactive')" />
</div>
<br/>
<div v-bind="color('default raised solid')" style="display:inline-flex;">
    <div :class="$style.swatch" v-bind="color('solid raised')" />
    <div :class="$style.swatch" v-bind="color('solid interactive raised')" />
</div>
<div v-bind="color('secondary raised solid')" style="display:inline-flex;">
    <div :class="$style.swatch" v-bind="color('solid raised')" />
    <div :class="$style.swatch" v-bind="color('solid interactive raised')" />
</div>
<div v-bind="color('primary raised solid')" style="display:inline-flex;">
    <div :class="$style.swatch" v-bind="color('solid raised')" />
    <div :class="$style.swatch" v-bind="color('solid interactive raised')" />
</div>

## Palette

The color palette consists of Blues, Reds, Grays, Beiges, as well as pastel blue/red/green/yellow.

<div :class="[$style.swatch, $style.small]" style="background:var(--fw-blue-010)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-blue-100)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-blue-400)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-blue-500)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-blue-600)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-blue-700)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-blue-800)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-blue-900)" />

<br/>

<div :class="[$style.swatch, $style.small]" style="background:var(--fw-red-010)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-red-100)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-red-400)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-red-500)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-red-600)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-red-700)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-red-800)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-red-900)" />

<br/>

<div :class="[$style.swatch, $style.small]" style="background:var(--fw-gray-100)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-gray-200)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-gray-300)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-gray-400)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-gray-500)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-gray-600)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-gray-700)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-gray-800)" />
<div :class="[$style.swatch, $style.tiny]" style="background:var(--fw-gray-850)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-gray-900)" />
<div :class="[$style.swatch, $style.tiny]" style="background:var(--fw-gray-950)" />
<div :class="[$style.swatch, $style.tiny]" style="background:var(--fw-gray-960)" />
<div :class="[$style.swatch, $style.tiny]" style="background:var(--fw-gray-970)" />

<br/>

<div :class="[$style.swatch, $style.small]" style="background:var(--fw-beige-100)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-beige-200)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-beige-300)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-beige-400)" />

---

<div :class="[$style.swatch, $style.small]" style="background:var(--fw-pastel-blue-1)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-pastel-blue-2)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-pastel-blue-3)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-pastel-blue-4)" />

<br/>

<div :class="[$style.swatch, $style.small]" style="background:var(--fw-pastel-red-1)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-pastel-red-2)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-pastel-red-3)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-pastel-red-4)" />

<br/>

<div :class="[$style.swatch, $style.small]" style="background:var(--fw-pastel-purple-1)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-pastel-purple-2)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-pastel-purple-3)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-pastel-purple-4)" />

<br/>

<div :class="[$style.swatch, $style.small]" style="background:var(--fw-pastel-green-1)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-pastel-green-2)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-pastel-green-3)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-pastel-green-4)" />

<br/>

<div :class="[$style.swatch, $style.small]" style="background:var(--fw-pastel-yellow-1)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-pastel-yellow-2)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-pastel-yellow-3)" />
<div :class="[$style.swatch, $style.small]" style="background:var(--fw-pastel-yellow-4)" />

In addition, we have a single shade of orange used for secondary indicators such as active tabs:

<div :class="$style.swatch" style="background:var(--fw-secondary)" />

## Theme

Many browsers automatically turn on "night mode" to lower the light emission of the screen. Users can override the browser theme in their settings menu.

In both "dark mode" and "light mode", the colors must provide adequate contrast and consistency.

## Semantic colors

We use semantic color variables that can mean a different shade depending on the currently chosen theme

- primary
- secondary (default)
- destructive

## Color variants

For each semantic color, we set a foreground and a background. In addition, we need to check context: A button should have a stronger shade when the mouse is hovering over it. When a surface is raised over another surface, it should have a stronger shade, too.

- ghost (default for most other things)

  - text color

- outline

  - border color

- solid (default for buttons)
  - bg color
  - border color

Variants can be made interactive and/or raised:

- no alteration (default)

- raised

  - text color
  - border color
  - bg color

- interactive

  - can be disabled
  - can be active
  - can be exact-active
  - can be hovering

- interactive-raised
  - combine `raised` and `interactive`

<style module>
    .swatch {
        border-radius: 2em;
        min-width: 3.2em;
        min-height: 3.2em;
        margin: 1ch;
        display: inline-flex;
        box-shadow: 1px 2px 7px #0003, 0px 0px 1px #0009;
        align-items:center;
        justify-items:center;
    }

    .small{
        margin: .25rem;
        min-width: 1.6em;
        min-height: 1.6em;
        box-shadow: 1px 2px 4px #0002, 0px 0px 1px #0007;
    }
    .tiny{
        margin:  .5rem .25rem;
        min-width: 1em;
        min-height: 1em;
        box-shadow: 1px 2px 4px #0002, 0px 0px 1px #0007;
    }
</style>
